# Dash Building Blocks
#### A Lightweight Auxiliary Framework for Writing Object-Oriented Dash Code.

[![CircleCI](https://circleci.com/gh/AlgorithmHub/dash_building_blocks.svg?style=svg)](https://circleci.com/gh/AlgorithmHub/dash_building_blocks)
[![Documentation Status](https://readthedocs.org/projects/dash-building-blocks/badge/?version=latest)](https://dash-building-blocks.readthedocs.io/en/latest/?badge=latest)

## Documentation
Read our [documentation](https://dash-building-blocks.readthedocs.io/en/latest/).
